@@ -1,4 +1,4 @@
-from PyObjCTools.TestSupport import TestCase, min_sdk_level
+from PyObjCTools.TestSupport import TestCase, min_sdk_level, min_os_level
 import CryptoTokenKit
 
 
@@ -19,3 +19,9 @@ class TestTKSmartCardToken(TestCase):
             3,
             b"o^@",
         )
+
+    @min_os_level("26.0")
+    def test_methods26_0(self):
+        self.assertArgIsOut(
+            CryptoTokenKit.TKSmartCardTokenSession.getSmartCardWithError_, 0
+        )
